==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/dbusmanager/leechcraft_dbusmanager_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>LeechCraft::Plugins::DBusManager::Core</name>
    <message>
        <source>LeechCraft D-Bus general interface</source>
        <translation>Основной интерфейс LeechCraft для системы D-Bus</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::DBusManager::DBusManager</name>
    <message>
        <source>DBus support for LeechCraft</source>
        <translation>Поддержка D-Bus для LeechCraft</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::DBusManager::General</name>
    <message>
        <source>Not found plugin %1.</source>
        <translation>Плагин %1 не найден.</translation>
    </message>
    <message>
        <source>Could not save icon for plugin %1 to PNG %2x%2</source>
        <translation>Невозможно сохранить иконку плагина %1 в PNG %2x%2</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::DBusManager::Tasks</name>
    <message>
        <source>Not found job holder %1.</source>
        <translation>Не найден плагин %1 с задачами.</translation>
    </message>
</context>
<context>
    <name>dbusmanagersettings</name>
    <message>
        <source>Environment</source>
        <translation>Окружение</translation>
    </message>
    <message>
        <source>KDE</source>
        <translation>KDE</translation>
    </message>
    <message>
        <source>Use notifications (KDE â¥ 4.4 or libnotify)</source>
        <translation>Использовать уведомления (KDE ≥ 4.4 или libnotify)</translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.75_rc20110524.tar.bz2: leechcraft-0.4.75_rc20110524/src/plugins/dbusmanager/leechcraft_dbusmanager_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>LeechCraft::Plugins::DBusManager::Core</name>
    <message>
        <source>LeechCraft D-Bus general interface</source>
        <translation>Основной интерфейс LeechCraft для системы D-Bus</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::DBusManager::DBusManager</name>
    <message>
        <source>DBus support for LeechCraft</source>
        <translation>Поддержка D-Bus для LeechCraft</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::DBusManager::General</name>
    <message>
        <source>Not found plugin %1.</source>
        <translation>Модуль %1 не найден.</translation>
    </message>
    <message>
        <source>Could not save icon for plugin %1 to PNG %2x%2</source>
        <translation>Невозможно сохранить значок модуля %1 в PNG %2×%2</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::DBusManager::Tasks</name>
    <message>
        <source>Not found job holder %1.</source>
        <translation>Не найден плагин %1 с задачами.</translation>
    </message>
</context>
<context>
    <name>dbusmanagersettings</name>
    <message>
        <source>Environment</source>
        <translation>Окружение</translation>
    </message>
    <message>
        <source>KDE</source>
        <translation>KDE</translation>
    </message>
    <message>
        <source>Use notifications (KDE â¥ 4.4 or libnotify)</source>
        <translation>Использовать уведомления (KDE ≥ 4.4 или libnotify)</translation>
    </message>
</context>
</TS>
